import {select,
        csv,
        scaleLinear,
        max, 
        scaleBand,
        axisLeft,
        axisBottom
       } from 'd3';
const csvUrl='https://gist.githubusercontent.com/snehareddygurram/9e08c5ca71badb1c6c90d5e1b7542bbe/raw/632246d3e8b29c0e8348e3924eb1440900c10553/greenhouse_dataset.csv'

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

      const tooltip = d3.select("body")
        .append("div")
        .attr("class","d3-tooltip")
        .style("position", "absolute")
        .style("z-index", "10")
        .style("visibility", "hidden")
        .style("padding", "15px")
        .style("background", "rgba(0,0,0,0.6)")
        .style("border-radius", "5px")
        .style("color", "#fff")
        .text("a simple tooltip");


const render = data => {
  const xValue = d => d.population;
  const yValue = d=>d.country;
  const margin = {top:20,right:20,left:100,bottom:20};
  const innerWidth = width - margin.left - margin.right
  const innerHeight  = height - margin.top - margin.bottom
  const xScale = scaleLinear()
    .domain([0,max(data,xValue)])
    .range([0,innerWidth]);
  
  const yScale =scaleBand()
  	.domain(data.map(yValue))
  	.range([0,innerHeight])
  	.padding(0.1);
  const yAxis = axisLeft(yScale);
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`)
  
  yAxis(g.append('g'));
  
  g.append('g').call(axisBottom(xScale))
  	.attr('transform',`translate(0,${innerHeight})`);

  g.append('text')
  	.attr('class','title')
  	.attr('y',0)
  	.attr('x',150)
  	.text("Greenhouse Gas in 2022 in household and industries");
  
  g.selectAll('rect').data(data)
  .enter().append('rect')
  	.attr('y',d => yScale(yValue(d)))
    .attr('width',d => xScale(xValue(d)))
  	.attr('height',yScale.bandwidth())
    .on("mouseover", function(event,d) {
      tooltip.html(`Greenhouse Gas: ${d.population} MtCO₂e`).style("visibility", "visible");
      d3.select(this)
        .attr("fill", shadeColor(bar_color, -15));
    })
    .on("mousemove", function(){
      tooltip
        .style("top", (event.pageY-10)+"px")
        .style("left",(event.pageX+10)+"px");
    })
    .on("mouseout", function() {
      tooltip.html(``).style("visibility", "hidden");
      d3.select(this).attr("fill", bar_color);
    });
  
  
  /*
    .on('mouseover', function (event,d) {
    	d3.select(this).transition()
        .duration('50')
        .attr('opacity', '.85');
      g.append("text")
        .attr("id", "tooltip")
        .attr("fill", "black")
    		.attr('x',event.pageX+100)
    		.attr('y',event.pageY)
        .text(d.population);
  	})
    .on('mouseout', function (event,d) {
      d3.select(this).transition()
        .duration('50')
        .attr('opacity', '1');
      d3.select("#tooltip")
        .remove();
  	})
    */
};

csv('data.csv').then(data => {
  data.forEach( d => {
    d.population  = +d.population;
  });
  render(data);
}